# scrapbook-ext
Extensions for [scrapbook](https://github.com/nteract/scrapbook)

## TODOs
- dill encoder

## Directory
- (internal) `.gitignore`
	... specifies the files to be ignored by [`git`](https://github.com/git/git) \
	... generated by the following command:
	```bash
	curl --parallel --location https://github.com/github/gitignore/raw/HEAD/{Python,Global/{Linux,Windows,macOS,Vim,SublimeText,VisualStudioCode}}.gitignore > .gitignore
	```
